UngroupCommand class

Constructors

UngroupCommand()
const

Properties

aliases → List<String>
Optional aliases that map to the same command.
no setterinherited
description → String
One-line description for help output.
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
The primary token used to invoke this command.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(CliContext context) → Future<int>
Unified execution entrypoint, implemented by commands.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

runCommand({required CliInvocation invocation, required Logger logger, required Prompter prompter, required GroupStore store}) → Future<int>